pub struct AdvancedQuantumAlgorithms {
pub default_config: AdvancedAlgorithmConfig,
}Expand description
Advanced quantum algorithms coordinator
This struct provides a unified interface for accessing all advanced quantum algorithms and managing their configurations and execution.
Fields
default_config: AdvancedAlgorithmConfigDefault configuration for algorithms
Implementations
Sourceimpl AdvancedQuantumAlgorithms
impl AdvancedQuantumAlgorithms
Sourcepub const fn with_config(config: AdvancedAlgorithmConfig) -> Self
pub const fn with_config(config: AdvancedAlgorithmConfig) -> Self
Create with custom configuration
Sourcepub fn solve<P>(
&self,
problem: &P,
config: Option<AdvancedAlgorithmConfig>,
) -> AdvancedQuantumResult<AnnealingResult<Vec<i32>>>where
P: Clone + 'static,
pub fn solve<P>(
&self,
problem: &P,
config: Option<AdvancedAlgorithmConfig>,
) -> AdvancedQuantumResult<AnnealingResult<Vec<i32>>>where
P: Clone + 'static,
Solve problem using selected advanced algorithm
Sourcepub fn optimize_problem(
&self,
problem: &QuboModel,
) -> AdvancedQuantumResult<AnnealingResult<AnnealingSolution>>
pub fn optimize_problem( &self, problem: &QuboModel, ) -> AdvancedQuantumResult<AnnealingResult<AnnealingSolution>>
Optimize a problem using the advanced quantum algorithms